@@ -153,6 +153,20 @@ Signalize action on a socket.
 
 Calls L<curl_multi_socket_action(3)>.
 
+=item assign( SOCKET, [VALUE] )
+
+Assigns some value to a socket file descriptor. Removes it is value is not
+specified.
+
+Calls L<curl_multi_assign(3)>.
+
+=item handles( )
+
+In list context returns easy handles attached to this multi.
+In scalar context returns number of easy handles attached.
+
+There is no libcurl equivalent.
+
 =item DESTROY( )
 
 Cleans up. It should not be called manually.
@@ -214,12 +228,13 @@ Special socket value for socket_action() method.
 =item CURLMOPT_SOCKETFUNCTION ( CURLMOPT_SOCKETDATA )
 
 Socket callback will be called only if socket_action() method is being used.
-It receives 5 arguments: easy handle, socket file number, poll action, an
-undefined value (for now), and CURLMOPT_SOCKETDATA value. It must return 0.
+It receives 6 arguments: multi handle, easy handle, socket file number, poll
+action, an undefined value (for now), and CURLMOPT_SOCKETDATA value. It must
+return 0.
 For more information reffer to L<curl_multi_socket_action(3)>.
 
  sub cb_socket {
-     my ( $easy, $socketfn, $action, $undef, $uservar ) = @_;
+     my ( $multi, $easy, $socketfn, $action, $undef, $uservar ) = @_;
      # ... register or deregister socket actions ...
      return 0;
  }
@@ -242,6 +257,9 @@ CURLMOPT_TIMERDATA value. Should return 0.
 
 L<WWW::CurlOO>
 L<WWW::CurlOO::Easy>
+L<WWW::CurlOO::examples(3pm)>
+L<libcurl-multi(3)>
+L<libcurl-errors(3)>
 
 =head1 COPYRIGHT
 
